==> scrollz_1.9.99.orig.tar.gz: scrollz-1.9.99/include/output.h <==
/*
 * output.h: header for output.c 
 *
 * Written By Michael Sandrof
 *
 * Copyright (c) 1990 Michael Sandrof.
 * Copyright (c) 1991, 1992 Troy Rollo.
 * Copyright (c) 1992-2003 Matthew R. Green.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: output.h,v 1.5 2003/01/08 20:00:54 f Exp $
 */

#ifndef __output_h_
#define __output_h_

#ifdef HAVE_STDARG_H
	void	put_it _((char *, ...));
	void	send_to_server _((char *, ...));
	void	say _((char *, ...));
	void	yell _((char *, ...));
	void	help_put_it _((char *, char *, ...));
# else
	void	put_it _(());
	void	send_to_server _(());
	void	say _(());
	void	yell _(());
	void	help_put_it _(());
#endif /* HAVE_STDARG_H */

 	void	refresh_screen _((u_int, char *));
extern	int	do_refresh_screen;
	void	init_screen _((void));
	void	put_file _((char *));

extern	FILE	*irclog_fp;

#endif /* __output_h_ */

==> scrollz_2.2.3.orig.tar.gz: scrollz-2.2.3.orig/include/output.h <==
/*
 * output.h: header for output.c 
 *
 * Written By Michael Sandrof
 *
 * Copyright (c) 1990 Michael Sandrof.
 * Copyright (c) 1991, 1992 Troy Rollo.
 * Copyright (c) 1992-2003 Matthew R. Green.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: output.h,v 1.6 2008-12-01 15:41:36 f Exp $
 */

#ifndef __output_h_
#define __output_h_

#ifdef HAVE_STDARG_H
	Window *put_it _((char *, ...));
	void	send_to_server _((char *, ...));
	Window *say _((char *, ...));
	void	yell _((char *, ...));
	void	help_put_it _((char *, char *, ...));
# else
	Window *put_it _(());
	void	send_to_server _(());
	Window *say _(());
	void	yell _(());
	void	help_put_it _(());
#endif /* HAVE_STDARG_H */

 	void	refresh_screen _((u_int, char *));
extern	int	do_refresh_screen;
	void	init_screen _((void));
	void	put_file _((char *));

extern	FILE	*irclog_fp;

#endif /* __output_h_ */
